==> tencentcloud-sdk-python-intl-en-3.0.593.tar.gz: tencentcloud-sdk-python-intl-en-3.0.593/tencentcloud/emr/v20190103/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Duplicate order. Please check the EMR console.
FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'

# Operation failed. The pods are not supported.
FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'

# Internal error.
INTERNALERROR = 'InternalError'

# An error occurred while calling another service API.
INTERNALERROR_ACCOUNTCGWERROR = 'InternalError.AccountCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CAMCGWERROR = 'InternalError.CamCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CAMERROR = 'InternalError.CamError'

# An error occurred while calling another service API.
INTERNALERROR_CBSCGWERROR = 'InternalError.CbsCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CBSERROR = 'InternalError.CbsError'

# An error occurred while calling another service API.
INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CDBERROR = 'InternalError.CdbError'

# CVM or CBS resources are insufficient, or the software is invalid.
INTERNALERROR_CHECKQUOTAERR = 'InternalError.CheckQuotaErr'

# An error occurred while calling another service API.
INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CVMERROR = 'InternalError.CvmError'

# An error occurred while calling another service API.
INTERNALERROR_KMSERROR = 'InternalError.KmsError'

# An error occurred while calling another service API.
INTERNALERROR_PROJECTCGWERROR = 'InternalError.ProjectCgwError'

# An error occurred when calling a security group API.
INTERNALERROR_SGERROR = 'InternalError.SgError'

# An error occurred while calling TKE.
INTERNALERROR_TKEERROR = 'InternalError.TKEError'

# An error occurred while calling another service API.
INTERNALERROR_TAGERROR = 'InternalError.TagError'

# An error occurred while calling another service API.
INTERNALERROR_TRADECGWERROR = 'InternalError.TradeCgwError'

# An error occurred while calling another service API.
INTERNALERROR_VPCCGWERROR = 'InternalError.VpcCgwError'

# An error occurred while calling another service API.
INTERNALERROR_VPCERROR = 'InternalError.VpcError'

# An error occurred while calling another service API.
INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Incorrect display policy.
INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'

# Parameter error.
INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'

# The number of common nodes is invalid.
INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'

# The number of master nodes is invalid.
INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'

# Invalid `AppId`.
INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'

# Invalid auto-renewal flag.
INVALIDPARAMETER_INVALIDAUTORENEW = 'InvalidParameter.InvalidAutoRenew'

# Invalid ClickHouse cluster.
INVALIDPARAMETER_INVALIDCLICKHOUSECLUSTER = 'InvalidParameter.InvalidClickHouseCluster'

# Invalid `ClientToken`.
INVALIDPARAMETER_INVALIDCLIENTTOKEN = 'InvalidParameter.InvalidClientToken'

# Invalid parameter: ClusterId.
INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'

# Invalid parameter.
INVALIDPARAMETER_INVALIDCOMMONDISKTYPE = 'InvalidParameter.InvalidCommonDiskType'

# Invalid component.
INVALIDPARAMETER_INVALIDCOMPONENT = 'InvalidParameter.InvalidComponent'

# The number of core nodes is invalid.
INVALIDPARAMETER_INVALIDCORECOUNT = 'InvalidParameter.InvalidCoreCount'

# The count must be greater than 0.
INVALIDPARAMETER_INVALIDCOUNT = 'InvalidParameter.InvalidCount'

# A scale-out request only applies to task nodes or core nodes.
INVALIDPARAMETER_INVALIDCOUNTNUM = 'InvalidParameter.InvalidCountNum'

# Error message: Invalid PodParameter.
INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomizedPodParam'

# Invalid disk size.
INVALIDPARAMETER_INVALIDDISKSIZE = 'InvalidParameter.InvalidDiskSize'

# Invalid EKS instance.
INVALIDPARAMETER_INVALIDEKSINSTANCE = 'InvalidParameter.InvalidEksInstance'

# Invalid `CustomConfig`.
INVALIDPARAMETER_INVALIDEXTENDFIELD = 'InvalidParameter.InvalidExtendField'

# Invalid cluster name.
INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'

# Invalid model.
INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'

# Invalid login settings.
INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'

# Invalid parameter.
INVALIDPARAMETER_INVALIDMASTERDISKTYPE = 'InvalidParameter.InvalidMasterDiskType'

# Invalid metadatabase URL.
INVALIDPARAMETER_INVALIDMETADATAJDBCURL = 'InvalidParameter.InvalidMetaDataJdbcUrl'

# Invalid metadata table type.
INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'

# Invalid target specification.
INVALIDPARAMETER_INVALIDMODIFYSPEC = 'InvalidParameter.InvalidModifySpec'

# Invalid `NodeType`.
INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'

# Invalid password.
INVALIDPARAMETER_INVALIDPASSWORD = 'InvalidParameter.InvalidPassword'

# Invalid billing mode.
INVALIDPARAMETER_INVALIDPAYMODE = 'InvalidParameter.InvalidPaymode'

# Invalid bootstrap script.
INVALIDPARAMETER_INVALIDPREEXECUTEDFILE = 'InvalidParameter.InvalidPreExecutedFile'

# Invalid product ID.
INVALIDPARAMETER_INVALIDPRODUCTID = 'InvalidParameter.InvalidProductId'

# Invalid project ID.
INVALIDPARAMETER_INVALIDPROJECTID = 'InvalidParameter.InvalidProjectId'

# Invalid resource ID.
INVALIDPARAMETER_INVALIDRESOURCEIDS = 'InvalidParameter.InvalidResourceIds'

# Invalid resource specification.
INVALIDPARAMETER_INVALIDRESOURCESPEC = 'InvalidParameter.InvalidResourceSpec'

# This EMR version does not support the security mode.
INVALIDPARAMETER_INVALIDSECURITYSUPPORT = 'InvalidParameter.InvalidSecuritySupport'

# Invalid security group ID.
INVALIDPARAMETER_INVALIDSERCURITYGRPUPID = 'InvalidParameter.InvalidSercurityGrpupId'

# The service name is invalid.
INVALIDPARAMETER_INVALIDSERVICENAME = 'InvalidParameter.InvalidServiceName'

# The `ServiceNodeInfo` parameter is invalid or incorrect.
INVALIDPARAMETER_INVALIDSERVICENODEINFO = 'InvalidParameter.InvalidServiceNodeInfo'

# The `InvalidSoftDeployInfo` parameter is invalid or incorrect.
INVALIDPARAMETER_INVALIDSOFTDEPLOYINFO = 'InvalidParameter.InvalidSoftDeployInfo'

# Invalid `SoftInfo`.
INVALIDPARAMETER_INVALIDSOFTINFO = 'InvalidParameter.InvalidSoftInfo'

# Incorrect parameter.
INVALIDPARAMETER_INVALIDSOFTWARE = 'InvalidParameter.InvalidSoftWare'

# The software name is invalid.
INVALIDPARAMETER_INVALIDSOFTWARENAME = 'InvalidParameter.InvalidSoftWareName'

# The software version is invalid.
INVALIDPARAMETER_INVALIDSOFTWAREVERSION = 'InvalidParameter.InvalidSoftWareVersion'

# Invalid subnet ID.
INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'

# Invalid high availability parameter.
INVALIDPARAMETER_INVALIDSUPPORTHA = 'InvalidParameter.InvalidSupportHA'

# The number of task nodes cannot exceed 20.
INVALIDPARAMETER_INVALIDTASKCOUNT = 'InvalidParameter.InvalidTaskCount'

# Invalid `timespan`.
INVALIDPARAMETER_INVALIDTIMESPAN = 'InvalidParameter.InvalidTimeSpan'

# Invalid `TimeUnit`.
INVALIDPARAMETER_INVALIDTIMEUNIT = 'InvalidParameter.InvalidTimeUnit'

# The TKE cluster ID is invalid, or the TKE cluster is not eligible.
INVALIDPARAMETER_INVALIDTKEINSTANCE = 'InvalidParameter.InvalidTkeInstance'

# Invalid unified metadatabase.
INVALIDPARAMETER_INVALIDUNIFYMETA = 'InvalidParameter.InvalidUnifyMeta'

# Invalid VPC ID.
INVALIDPARAMETER_INVALIDVPCID = 'InvalidParameter.InvalidVpcId'

# Invalid AZ.
INVALIDPARAMETER_INVALIDZONE = 'InvalidParameter.InvalidZone'

# Invalid parameter. Necessary components are missing.
INVALIDPARAMETER_NOTCONTAINMUSTSELECTSOFTWARE = 'InvalidParameter.NotContainMustSelectSoftware'

# Invalid sorting field.
INVALIDPARAMETER_ORDERFIELDNOTMATCH = 'InvalidParameter.OrderFieldNotMatch'

# The billing mode and resource do not match.
INVALIDPARAMETER_PAYMODERESOURCENOTMATCH = 'InvalidParameter.PayModeResourceNotMatch'

# The project does not match the resource.
INVALIDPARAMETER_PROJECTRESOURCENOTMATCH = 'InvalidParameter.ProjectResourceNotMatch'

# There is an invalid product component.
INVALIDPARAMETER_SOFTWARENOTINPRODUCT = 'InvalidParameter.SoftwareNotInProduct'

# The policy is not authorized.
INVALIDPARAMETER_UNGRANTEDPOLICY = 'InvalidParameter.UngrantedPolicy'

# The role is not authorized.
INVALIDPARAMETER_UNGRANTEDROLE = 'InvalidParameter.UngrantedRole'

# The AZ and resource do not match.
INVALIDPARAMETER_ZONERESOURCENOTMATCH = 'InvalidParameter.ZoneResourceNotMatch'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The TKE cluster ID is invalid, or the TKE cluster is not eligible.
INVALIDPARAMETERVALUE_INVALIDTKEINSTANCE = 'InvalidParameterValue.InvalidTkeInstance'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# The instance is under workflow.
RESOURCEINUSE_INSTANCEINPROCESS = 'ResourceInUse.InstanceInProcess'

# The disk specification is insufficient.
RESOURCEINSUFFICIENT_DISKINSUFFICIENT = 'ResourceInsufficient.DiskInsufficient'

# The node specification is unsupported or has been sold out.
RESOURCEINSUFFICIENT_INSTANCEINSUFFICIENT = 'ResourceInsufficient.InstanceInsufficient'

# The instance was not found.
RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'

# No hardware information found.
RESOURCENOTFOUND_HARDWAREINFONOTFOUND = 'ResourceNotFound.HardwareInfoNotFound'

# The instance was not found.
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# Unable to find the monitoring metadata.
RESOURCENOTFOUND_RESOURCENOTFOUND = 'ResourceNotFound.ResourceNotFound'

# No corresponding subnet found.
RESOURCENOTFOUND_SUBNETNOTFOUND = 'ResourceNotFound.SubnetNotFound'

# Preset components of the TKE cluster are not deployed.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  
RESOURCENOTFOUND_TKEPRECONDITIONNOTFOUND = 'ResourceNotFound.TKEPreconditionNotFound'

# No specified tag found.
RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'

# There is no default value of the current resource spec.
RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'

# The resources have been sold out.
RESOURCESSOLDOUT = 'ResourcesSoldOut'

# The CBS resources have been sold out.
RESOURCESSOLDOUT_CBSSOLDOUT = 'ResourcesSoldOut.CbsSoldOut'

# CVM instances have been sold out.
RESOURCESSOLDOUT_CVMSOLDOUT = 'ResourcesSoldOut.CvmSoldOut'

# Unknown parameter.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# This operation is not supported.
UNSUPPORTEDOPERATION_SERVICENOTSUPPORT = 'UnsupportedOperation.ServiceNotSupport'

==> tencentcloud-sdk-python-intl-en-3.0.607.tar.gz: tencentcloud-sdk-python-intl-en-3.0.607/tencentcloud/emr/v20190103/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# 
FAILEDOPERATION_CHECKIFSUPPORTPODSTRETCH = 'FailedOperation.CheckIfSupportPodStretch'

# Duplicate order. Please check the EMR console.
FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'

# Operation failed. The pods are not supported.
FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'

# Internal error.
INTERNALERROR = 'InternalError'

# An error occurred while calling another service API.
INTERNALERROR_ACCOUNTCGWERROR = 'InternalError.AccountCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CAMCGWERROR = 'InternalError.CamCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CAMERROR = 'InternalError.CamError'

# An error occurred while calling another service API.
INTERNALERROR_CBSCGWERROR = 'InternalError.CbsCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CBSERROR = 'InternalError.CbsError'

# An error occurred while calling another service API.
INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CDBERROR = 'InternalError.CdbError'

# CVM or CBS resources are insufficient, or the software is invalid.
INTERNALERROR_CHECKQUOTAERR = 'InternalError.CheckQuotaErr'

# An error occurred while calling another service API.
INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'

# An error occurred while calling another service API.
INTERNALERROR_CVMERROR = 'InternalError.CvmError'

# Error in calling EKS.
INTERNALERROR_EKSERROR = 'InternalError.EKSError'

# An error occurred while calling another service API.
INTERNALERROR_KMSERROR = 'InternalError.KmsError'

# An error occurred while calling another service API.
INTERNALERROR_PROJECTCGWERROR = 'InternalError.ProjectCgwError'

# An error occurred when calling a security group API.
INTERNALERROR_SGERROR = 'InternalError.SgError'

# An error occurred while calling TKE.
INTERNALERROR_TKEERROR = 'InternalError.TKEError'

# An error occurred while calling another service API.
INTERNALERROR_TAGERROR = 'InternalError.TagError'

# An error occurred while calling another service API.
INTERNALERROR_TRADECGWERROR = 'InternalError.TradeCgwError'

# An error occurred while calling another service API.
INTERNALERROR_VPCCGWERROR = 'InternalError.VpcCgwError'

# An error occurred while calling another service API.
INTERNALERROR_VPCERROR = 'InternalError.VpcError'

# An error occurred while calling another service API.
INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Incorrect display policy.
INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'

# Parameter error.
INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'

# The number of common nodes is invalid.
INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'

# The number of master nodes is invalid.
INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'

# Invalid `AppId`.
INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'

# Invalid auto-renewal flag.
INVALIDPARAMETER_INVALIDAUTORENEW = 'InvalidParameter.InvalidAutoRenew'

# Invalid ClickHouse cluster.
INVALIDPARAMETER_INVALIDCLICKHOUSECLUSTER = 'InvalidParameter.InvalidClickHouseCluster'

# Invalid `ClientToken`.
INVALIDPARAMETER_INVALIDCLIENTTOKEN = 'InvalidParameter.InvalidClientToken'

# Invalid parameter: ClusterId.
INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'

# Invalid parameter.
INVALIDPARAMETER_INVALIDCOMMONDISKTYPE = 'InvalidParameter.InvalidCommonDiskType'

# Invalid component.
INVALIDPARAMETER_INVALIDCOMPONENT = 'InvalidParameter.InvalidComponent'

# The number of core nodes is invalid.
INVALIDPARAMETER_INVALIDCORECOUNT = 'InvalidParameter.InvalidCoreCount'

# The count must be greater than 0.
INVALIDPARAMETER_INVALIDCOUNT = 'InvalidParameter.InvalidCount'

# A scale-out request only applies to task nodes or core nodes.
INVALIDPARAMETER_INVALIDCOUNTNUM = 'InvalidParameter.InvalidCountNum'

# Error message: Invalid PodParameter.
INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomizedPodParam'

# Invalid disk size.
INVALIDPARAMETER_INVALIDDISKSIZE = 'InvalidParameter.InvalidDiskSize'

# Invalid EKS instance.
INVALIDPARAMETER_INVALIDEKSINSTANCE = 'InvalidParameter.InvalidEksInstance'

# Invalid `CustomConfig`.
INVALIDPARAMETER_INVALIDEXTENDFIELD = 'InvalidParameter.InvalidExtendField'

# Invalid cluster name.
INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'

# Invalid model.
INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'

# Invalid login settings.
INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'

# Invalid parameter.
INVALIDPARAMETER_INVALIDMASTERDISKTYPE = 'InvalidParameter.InvalidMasterDiskType'

# Invalid metadatabase URL.
INVALIDPARAMETER_INVALIDMETADATAJDBCURL = 'InvalidParameter.InvalidMetaDataJdbcUrl'

# Invalid metadata table type.
INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'

# Invalid target specification.
INVALIDPARAMETER_INVALIDMODIFYSPEC = 'InvalidParameter.InvalidModifySpec'

# Invalid `NodeType`.
INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'

# Invalid password.
INVALIDPARAMETER_INVALIDPASSWORD = 'InvalidParameter.InvalidPassword'

# Invalid billing mode.
INVALIDPARAMETER_INVALIDPAYMODE = 'InvalidParameter.InvalidPaymode'

# Invalid bootstrap script.
INVALIDPARAMETER_INVALIDPREEXECUTEDFILE = 'InvalidParameter.InvalidPreExecutedFile'

# Invalid product ID.
INVALIDPARAMETER_INVALIDPRODUCTID = 'InvalidParameter.InvalidProductId'

# Invalid project ID.
INVALIDPARAMETER_INVALIDPROJECTID = 'InvalidParameter.InvalidProjectId'

# Invalid resource ID.
INVALIDPARAMETER_INVALIDRESOURCEIDS = 'InvalidParameter.InvalidResourceIds'

# Invalid resource specification.
INVALIDPARAMETER_INVALIDRESOURCESPEC = 'InvalidParameter.InvalidResourceSpec'

# This EMR version does not support the security mode.
INVALIDPARAMETER_INVALIDSECURITYSUPPORT = 'InvalidParameter.InvalidSecuritySupport'

# Invalid security group ID.
INVALIDPARAMETER_INVALIDSERCURITYGRPUPID = 'InvalidParameter.InvalidSercurityGrpupId'

# The service name is invalid.
INVALIDPARAMETER_INVALIDSERVICENAME = 'InvalidParameter.InvalidServiceName'

# The `ServiceNodeInfo` parameter is invalid or incorrect.
INVALIDPARAMETER_INVALIDSERVICENODEINFO = 'InvalidParameter.InvalidServiceNodeInfo'

# The `InvalidSoftDeployInfo` parameter is invalid or incorrect.
INVALIDPARAMETER_INVALIDSOFTDEPLOYINFO = 'InvalidParameter.InvalidSoftDeployInfo'

# Invalid `SoftInfo`.
INVALIDPARAMETER_INVALIDSOFTINFO = 'InvalidParameter.InvalidSoftInfo'

# Incorrect parameter.
INVALIDPARAMETER_INVALIDSOFTWARE = 'InvalidParameter.InvalidSoftWare'

# The software name is invalid.
INVALIDPARAMETER_INVALIDSOFTWARENAME = 'InvalidParameter.InvalidSoftWareName'

# The software version is invalid.
INVALIDPARAMETER_INVALIDSOFTWAREVERSION = 'InvalidParameter.InvalidSoftWareVersion'

# Invalid subnet ID.
INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'

# Invalid high availability parameter.
INVALIDPARAMETER_INVALIDSUPPORTHA = 'InvalidParameter.InvalidSupportHA'

# The number of task nodes cannot exceed 20.
INVALIDPARAMETER_INVALIDTASKCOUNT = 'InvalidParameter.InvalidTaskCount'

# Invalid `timespan`.
INVALIDPARAMETER_INVALIDTIMESPAN = 'InvalidParameter.InvalidTimeSpan'

# Invalid `TimeUnit`.
INVALIDPARAMETER_INVALIDTIMEUNIT = 'InvalidParameter.InvalidTimeUnit'

# The TKE cluster ID is invalid, or the TKE cluster is not eligible.
INVALIDPARAMETER_INVALIDTKEINSTANCE = 'InvalidParameter.InvalidTkeInstance'

# Invalid unified metadatabase.
INVALIDPARAMETER_INVALIDUNIFYMETA = 'InvalidParameter.InvalidUnifyMeta'

# Invalid VPC ID.
INVALIDPARAMETER_INVALIDVPCID = 'InvalidParameter.InvalidVpcId'

# Invalid AZ.
INVALIDPARAMETER_INVALIDZONE = 'InvalidParameter.InvalidZone'

# Invalid parameter. Necessary components are missing.
INVALIDPARAMETER_NOTCONTAINMUSTSELECTSOFTWARE = 'InvalidParameter.NotContainMustSelectSoftware'

# Invalid sorting field.
INVALIDPARAMETER_ORDERFIELDNOTMATCH = 'InvalidParameter.OrderFieldNotMatch'

# The billing mode and resource do not match.
INVALIDPARAMETER_PAYMODERESOURCENOTMATCH = 'InvalidParameter.PayModeResourceNotMatch'

# The project does not match the resource.
INVALIDPARAMETER_PROJECTRESOURCENOTMATCH = 'InvalidParameter.ProjectResourceNotMatch'

# There is an invalid product component.
INVALIDPARAMETER_SOFTWARENOTINPRODUCT = 'InvalidParameter.SoftwareNotInProduct'

# The policy is not authorized.
INVALIDPARAMETER_UNGRANTEDPOLICY = 'InvalidParameter.UngrantedPolicy'

# The role is not authorized.
INVALIDPARAMETER_UNGRANTEDROLE = 'InvalidParameter.UngrantedRole'

# The AZ and resource do not match.
INVALIDPARAMETER_ZONERESOURCENOTMATCH = 'InvalidParameter.ZoneResourceNotMatch'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The TKE cluster ID is invalid, or the TKE cluster is not eligible.
INVALIDPARAMETERVALUE_INVALIDTKEINSTANCE = 'InvalidParameterValue.InvalidTkeInstance'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# The instance is under workflow.
RESOURCEINUSE_INSTANCEINPROCESS = 'ResourceInUse.InstanceInProcess'

# The disk specification is insufficient.
RESOURCEINSUFFICIENT_DISKINSUFFICIENT = 'ResourceInsufficient.DiskInsufficient'

# The node specification is unsupported or has been sold out.
RESOURCEINSUFFICIENT_INSTANCEINSUFFICIENT = 'ResourceInsufficient.InstanceInsufficient'

# The instance was not found.
RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'

# No hardware information found.
RESOURCENOTFOUND_HARDWAREINFONOTFOUND = 'ResourceNotFound.HardwareInfoNotFound'

# The instance was not found.
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# Unable to find the monitoring metadata.
RESOURCENOTFOUND_RESOURCENOTFOUND = 'ResourceNotFound.ResourceNotFound'

# No corresponding subnet found.
RESOURCENOTFOUND_SUBNETNOTFOUND = 'ResourceNotFound.SubnetNotFound'

# Preset components of the TKE cluster are not deployed.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  
RESOURCENOTFOUND_TKEPRECONDITIONNOTFOUND = 'ResourceNotFound.TKEPreconditionNotFound'

# No specified tag found.
RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'

# There is no default value of the current resource spec.
RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'

# The resources have been sold out.
RESOURCESSOLDOUT = 'ResourcesSoldOut'

# The CBS resources have been sold out.
RESOURCESSOLDOUT_CBSSOLDOUT = 'ResourcesSoldOut.CbsSoldOut'

# CVM instances have been sold out.
RESOURCESSOLDOUT_CVMSOLDOUT = 'ResourcesSoldOut.CvmSoldOut'

# Unknown parameter.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# This operation is not supported.
UNSUPPORTEDOPERATION_SERVICENOTSUPPORT = 'UnsupportedOperation.ServiceNotSupport'
